{ Unit: Unit1
  ===========================================================================

  The contents of this file are subject to the Bluecave Public License V 1.1
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Example how to use TBcOpenDialog and/or TBcSaveDialog.

    Example how to create "Browse for WAV files" dialog with preview.

  History:

    2001-10-11: Added sound browse dialog
    2001-10-04: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, BcDialogs, ExtDlgs, ImgList, Buttons;

type
  TForm1 = class(TForm)
    BcOpenDialog1: TBcOpenDialog;
    Button1: TButton;
    BcOpenDialog2: TBcOpenDialog;
    BtnSound: TButton;
    Label1: TLabel;
    Images: TImageList;
    procedure Button1Click(Sender: TObject);
    function FormHelp(Command: Word; Data: Integer;
      var CallHelp: Boolean): Boolean;
    procedure BcOpenDialog1AddControls(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure BcOpenDialog1SelectionChange(Sender: TObject);
    procedure BtnSoundClick(Sender: TObject);
    procedure BcOpenDialog2SelectionChange(Sender: TObject);
    procedure BcOpenDialog2Close(Sender: TObject);
    procedure BcOpenDialog2AddControls(Sender: TObject);
    procedure BrowseSoundPreviewClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses MMSystem;

{$R *.DFM}

procedure TForm1.Button1Click(Sender: TObject);
begin
  if BcOpenDialog1.Execute then
    ShowMessage('Selected file: ' + BcOpenDialog1.FileName)
end;

function TForm1.FormHelp(Command: Word; Data: Integer;
  var CallHelp: Boolean): Boolean;
begin
  if (Command = HELP_CONTEXT)	and (Data = -1) then
    BcOpenDialog1.ClickCancel;
  CallHelp := False;
  Result := True;
  ShowMessage('Selected default');
end;

procedure TForm1.BcOpenDialog1AddControls(Sender: TObject);
var R: TRect;
begin
  with BcOpenDialog1 do
  begin
    R := ClientRect;
    AddButton('Print It!', Button2Click, R.Left + 11, R.Bottom - 31, 75, 23);
    AddButton('Mail It!', Button2Click, R.Left + 11 + 75 + 4, R.Bottom - 31, 75, 23);
  end;
end;

procedure TForm1.Button2Click(Sender: TObject);
begin
  Windows.MessageBox(BcOpenDialog1.Handle, 'Feature not implemented!', 'Just example!', MB_OK);
end;

procedure TForm1.BcOpenDialog1SelectionChange(Sender: TObject);
var S: string;
begin
  S := ExtractFileExt(BcOpenDialog1.FileName);
  Delete(S, 1, 1);
  S := UpperCase(S);
  if S = '' then
    S := 'Select'
  else if (S = 'EXE') or (S = 'BAT') or (S = 'COM') then
    S := 'Run'
  else if (S = 'TXT') or (S = 'DOC') then
    S := 'Print'
  else if (S = 'PAS') or (S = 'DPR') then
    S := 'Edit'
  else if (S = 'WAV') or (S = 'MP3') then
    S := 'Play'
  else
    S := 'View';
  BcOpenDialog1.Captions.OkButton := S;
end;

procedure TForm1.BtnSoundClick(Sender: TObject);
begin
  Tag := 1; // do not run sound preview on first time
  if BcOpenDialog2.Execute then
    ShowMessage('Selected ' + BcOpenDialog2.FileName);
end;

procedure TForm1.BcOpenDialog2SelectionChange(Sender: TObject);
begin
  if TBcOpenDialog(Sender).Tag = 0 then
    BrowseSoundPreviewClick(Sender);
  TBcOpenDialog(Sender).Tag := 0;
end;

procedure TForm1.BcOpenDialog2Close(Sender: TObject);
begin
  PlaySound(nil, 0, 0); // stop any playing sound
end;

procedure TForm1.BcOpenDialog2AddControls(Sender: TObject);
var
  R, ItemRect: TRect;
  Btn: TSpeedButton;
begin
  with TBcOpenDialog(Sender) do
  begin
    { enlarge the dialog }
    R := WindowRect;
    Inc(R.Bottom, 32);
    WindowRect := R;

    R := ClientRect;

    // ItemRect makes sure that the control is aligned at right position in the dialog
    // because the dialog's own control positions might be different in different
    // Windows versions.

    ItemRect := DialogControlRect[dcFileTypeLabel];
    AddLabel('Preview:', ItemRect.Left, R.Bottom - 26);

    Btn := TSpeedButton.Create(TBcOpenDialog(Sender));
    Images.GetBitmap(0, Btn.Glyph);
    Btn.SetBounds(0, 0, 22, 22);
    Btn.OnClick := BrowseSoundPreviewClick;

    ItemRect := DialogControlRect[dcFileTypeCombobox];
    AddControl(Btn, ItemRect.Left, R.Bottom - 30);
  end;
end;

procedure TForm1.BrowseSoundPreviewClick(Sender: TObject);
 var
  Dlg: TBcOpenDialog;
begin
  { get the dialog. two checks because this event is used
    from two different places (onpreviewclick and onselectionchange) }
  if Sender is TBcOpenDialog then
    Dlg := TBcOpenDialog(Sender)
  else if Sender is TControl then
    Dlg := (TControl(Sender).Owner as TBcOpenDialog)
  else
    Exit;

  { play the sound file }  
  PlaySound(PChar(Dlg.FileName), 0,
    SND_FILENAME or SND_NODEFAULT or SND_NOWAIT or SND_ASYNC);
end;

end.
