{ Unit: BcAPITimer
  ===========================================================================

  The contents of this file are subject to the Bluecave Limited License V 1.0
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001-2002 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001-2002 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    This is similar and has same functionalily as VCL TTimer. Difference
    is that TBcAPITimer does not use any window handles for the timer.
    There are two versions of the timer. And TObject descand and one
    TComponent. The TObject version can be found from BcAPITimerObject unit.

    For usage read the help for TTimer.

  History:

    2001-11-27: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcAPITimer;

interface

uses Windows, Classes, SysUtils, BcAPITimerObject;

const
  DefaultEnabled = True;

type
  TBcAPITimer = class(TComponent)
  private
    FEnabled: Boolean;
    FBcAPITimerObject: TBcAPITimerObject;
    function GetEnabled: Boolean;
    function GetInterval: Cardinal;
    function GetOnTimer: TBcTimerEvent;
    function GetTimerHandle: THandle;
    procedure SetEnabled(const Value: Boolean);
    procedure SetInterval(const Value: Cardinal);
    procedure SetOnTimer(const Value: TBcTimerEvent);
  protected
    procedure Loaded; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property TimerHandle: THandle read GetTimerHandle;
    property Enabled: Boolean read GetEnabled write SetEnabled default DefaultEnabled;
    property Interval: Cardinal read GetInterval write SetInterval;

    property OnTimer: TBcTimerEvent read GetOnTimer write SetOnTimer;
  end;

implementation

{ TBcAPITimer }

constructor TBcAPITimer.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FBcAPITimerObject := TBcAPITimerObject.Create(Self);
  FEnabled := True;
end;

destructor TBcAPITimer.Destroy;
begin
  FreeAndNil(FBcAPITimerObject);
  inherited Destroy;
end;

function TBcAPITimer.GetEnabled: Boolean;
begin
  Result := FEnabled;
end;

function TBcAPITimer.GetInterval: Cardinal;
begin
  Result := FBcAPITimerObject.Interval;
end;

function TBcAPITimer.GetOnTimer: TBcTimerEvent;
begin
  Result := FBcAPITimerObject.OnTimer;
end;

function TBcAPITimer.GetTimerHandle: THandle;
begin
  Result := FBcAPITimerObject.TimerHandle;
end;

procedure TBcAPITimer.Loaded;
begin
  inherited;
  if Enabled then
  begin
    FBcAPITimerObject.Enabled := Enabled;
  end;
end;

procedure TBcAPITimer.SetEnabled(const Value: Boolean);
begin
  FEnabled := Value;
  if not ((csDesigning in ComponentState) or (csLoading in ComponentState) or
    (csReading	in ComponentState)) then
  begin
    FBcAPITimerObject.Enabled := Value;
  end;
end;

procedure TBcAPITimer.SetInterval(const Value: Cardinal);
begin
  FBcAPITimerObject.Interval := Value;
end;

procedure TBcAPITimer.SetOnTimer(const Value: TBcTimerEvent);
begin
  FBcAPITimerObject.OnTimer := Value;
end;

end.
